@@ -214,7 +214,7 @@ class MetadataFiltersContainer:
 
         default_effect_conditions = default_effect_op.join(
             [
-                f"({self._get_sql_field_condition(f, column_mapping, encoder, force_lowercase)})"
+                self._get_sql_field_condition(f, column_mapping, encoder, force_lowercase)
                 for f in default_effect_filters
             ]
         )
@@ -224,13 +224,15 @@ class MetadataFiltersContainer:
                 for f in other_effect_filters
             ]
         )
-        conditions = default_effect_conditions
-        if conditions and other_effect_conditions:
-            conditions += default_effect_op
-            conditions += "(" + other_effect_conditions + ")"
-        elif not conditions:
-            conditions = other_effect_conditions
-        return f"({conditions})" if conditions else ""
+
+        if default_effect_conditions and other_effect_conditions:
+            return f"(({default_effect_conditions}){default_effect_op}({other_effect_conditions}))"
+        elif default_effect_conditions:
+            return f"({default_effect_conditions})"
+        elif other_effect_conditions:
+            return f"({other_effect_conditions})"
+        else:
+            return None
 
     @staticmethod
     def _get_sql_field_condition(
@@ -238,7 +240,7 @@ class MetadataFiltersContainer:
         column_mapping: Dict,
         encoder: Callable[[str, str, FilterType], str],
         force_lowercase: Optional[bool] = True,
-    ):
+    ) -> str:
         # The comparison is performed case-insensitive (check MetadataFilter._safe_match)
         # We can use LOWER here since it is part of standard SQL (like AND/OR/NOT), so including it
         # here is a way to make sure that all comparisons are case-insensitive in the SQL sentences
@@ -255,4 +257,6 @@ class MetadataFiltersContainer:
                 if getattr(mf, field) is not None
             ]
         )
+        if not conditions:
+            return ""
         return f"NOT({conditions})" if mf.effect == FilterEffectType.BLOCK else f"({conditions})"
