@@ -6,8 +6,7 @@ from pycarlo.common.files import BytesFileReader, JsonFileReader, TextFileReader
 
 
 class FileReaderTests(TestCase):
-
-    test_file_path = f'{Path(__file__).parent}/data.json'
+    test_file_path = f"{Path(__file__).parent}/data.json"
 
     def test_readers(self):
         as_bytes = BytesFileReader(self.test_file_path).read()
@@ -16,13 +15,12 @@ class FileReaderTests(TestCase):
 
         self.assertEqual(as_dict, json.loads(as_bytes))
         self.assertEqual(as_dict, json.loads(as_str))
-        self.assertEqual(as_bytes, as_str.encode('utf-8'))
+        self.assertEqual(as_bytes, as_str.encode("utf-8"))
 
 
 class FileUtilsTests(TestCase):
-
     def test_to_path(self):
-        path_as_str = 'some/relative/path'
+        path_as_str = "some/relative/path"
         path = to_path(path_as_str)
 
         self.assertIsInstance(path, Path)
