@@ -619,7 +619,23 @@ class TestDatasetFiltering(TestCase):
         query = limits.get_sql_conditions(
             {"project": "database", "dataset": "schema"}, _redshift_encoder
         )
-        self.assertTrue(query)
+        self.assertEqual(query, "(NOT(LOWER(database)='project_2' AND LOWER(schema)='dataset_1'))")
+
+    def test_no_matching_mappings(self):
+        filters = MetadataAllowBlockList(
+            filters=[
+                MetadataFilter(project="allowed_project", effect=FilterEffectType.ALLOW),
+            ],
+        )
+        limits = MetadataFiltersContainer(metadata_filters=filters)
+        query = limits.get_sql_conditions(
+            {
+                "dataset": "TABLE_SCHEMA",
+                "table_name": "TABLE_NAME",
+            },
+            _redshift_encoder,
+        )
+        self.assertIsNone(query)
 
     def test_case_insensitive_comparison_exact_match(self):
         filters = MetadataAllowBlockList(
